API
===
.. currentmodule:: biobroker.api

.. autosummary::
   :nosignatures:

    GenericApi
    BsdApi


.. automodule:: biobroker.api
   :members:
   :undoc-members:
   :show-inheritance:



Exceptions
----------

.. automodule:: biobroker.api.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
